@@ -8,6 +8,17 @@ CLI_CONFIG = {
     "log_fmt_console": {"dyne": "__cli__", "subcommands": ["_global_"]},
     "log_datefmt": {"dyne": "__cli__", "subcommands": ["_global_"]},
     "log_plugin": {"dyne": "__cli__", "subcommands": ["_global_"]},
+    "log_handler_options": {
+        "dyne": "__cli__",
+        "subcommands": ["_global_"],
+        "nargs": "*",
+    },
+    "version": {
+        "dyne": "__cli__",
+        "default": False,
+        "action": "store_true",
+        "help": "Display version information",
+    },
 }
 
 CONFIG = {
@@ -47,9 +58,17 @@ CONFIG = {
         "help": "The logging plugin to use",
         "group": "Logging Options",
     },
+    "log_handler_options": {
+        "dyne": "__cli__",
+        "default": [],
+        "help": "kwargs that should be passed to the logging handler used by the log_plugin",
+        "group": "Logging Options",
+    },
 }
-SUBCOMMANDS = {}
 DYNE = {
+    "args": ["args"],
+    "comps": ["comps"],
     "config": ["config"],
     "log": ["log"],
+    "render": ["render"],
 }
